@@ -1,5 +1,5 @@
 char	netsh_id[]="\
-@(#)netsh.c (c) Copyright 1993-2004 Hewlett-Packard Company. Version 2.4.0";
+@(#)netsh.c (c) Copyright 1993-2004 Hewlett-Packard Company. Version 2.4.3";
 
 
 /****************************************************************/
@@ -81,9 +81,6 @@ double atof(const char *);
 #include "nettest_sctp.h"
 #endif
 
-#ifdef DO_DNS
-#include "nettest_dns.h"
-#endif /* DO_DNS */
 
 /************************************************************************/
 /*									*/
@@ -94,7 +91,7 @@ double atof(const char *);
  /* Some of the args take optional parameters. Since we are using */
  /* getopt to parse the command line, we will tell getopt that they do */
  /* not take parms, and then look for them ourselves */
-#define GLOBAL_CMD_LINE_ARGS "A:a:b:B:CcdDf:F:H:hi:I:k:K:l:L:n:O:o:P:p:t:T:v:W:w:46"
+#define GLOBAL_CMD_LINE_ARGS "A:a:b:B:CcdDf:F:H:hi:I:k:K:l:L:n:NO:o:P:p:t:T:v:W:w:46"
 
 /************************************************************************/
 /*									*/
@@ -220,6 +217,9 @@ int	af = AF_INET;
 /* did someone request processor affinity? */
 int cpu_binding_requested = 0;
 
+/* are we not establishing a control connection? */
+int no_control = 0;
+
 char netserver_usage[] = "\n\
 Usage: netserver [options] \n\
 \n\
@@ -237,7 +237,7 @@ Options:\n\
    compiler happy when compiling for x86_32.  fix from Spencer
    Frink.  */
 
-char netperf_usage[] = "\n\
+char netperf_usage1[] = "\n\
 Usage: netperf [global options] -- [test options] \n\
 \n\
 Global options:\n\
@@ -261,13 +261,15 @@ Global options:\n\
     -o send,recv      Set the local send,recv buffer offsets\n\
     -O send,recv      Set the remote send,recv buffer offset\n\
     -n numcpu         Set the number of processors for CPU util\n\
+    -N                Establish no control connection, do 'send' side only\n\
     -p port,lport*    Specify netserver port number and/or local port\n\
     -P 0|1            Don't/Do display test headers\n\
     -t testname       Specify test to perform\n\
     -T lcpu,rcpu      Request netperf/netserver be bound to local/remote cpu\n\
     -v verbosity      Specify the verbosity level\n\
-    -W send,recv      Set the number of send,recv buffers\n\
-\n\
+    -W send,recv      Set the number of send,recv buffers\n";
+
+char netperf_usage2[] = "\n\
 For those options taking two parms, at least one must be specified;\n\
 specifying one value without a comma will set both parms to that\n\
 value, specifying a value with a leading comma will set just the second\n\
@@ -432,6 +434,7 @@ set_defaults()
   iteration_max = 1;
   interval = 0.05; /* five percent? */
 
+  no_control = 0;
   strcpy(fill_file,"");
 }
      
@@ -446,7 +449,8 @@ print_netserver_usage()
 void
 print_netperf_usage()
 {
-  fwrite(netperf_usage, sizeof(char), strlen(netperf_usage),  stderr);
+  fwrite(netperf_usage1, sizeof(char), strlen(netperf_usage1),  stderr);
+  fwrite(netperf_usage2, sizeof(char), strlen(netperf_usage2),  stderr);
 }
 
 void
@@ -606,6 +610,9 @@ scan_cmd_line(int argc, char *argv[])
     case 'n':
       shell_num_cpus = atoi(optarg);
       break;
+    case 'N':
+      no_control = 1;
+      break;
     case 'o':
       /* set the local offsets */
       break_args(optarg,arg1,arg2);
@@ -822,6 +829,18 @@ scan_cmd_line(int argc, char *argv[])
     }
   }
 
+  /* so, if we aren't even going to establish a control connection we
+     should set certain "remote" settings to reflect this, regardless
+     of what else may have been set on the command line */
+  if (no_control) {
+    remote_recv_align = -1;
+    remote_send_align = -1;
+    remote_send_offset = -1;
+    remote_recv_offset = -1;
+    remote_cpu_rate = (float)-1.0;
+    remote_cpu_usage = 0;
+  }
+
   /* parsing test-specific options used to be conditional on there
     being a "--" in the option stream.  however, some of the tests
     have other initialization happening in their "scan" routines so we
@@ -889,13 +908,6 @@ scan_cmd_line(int argc, char *argv[])
     }
 #endif
 
-#ifdef DO_DNS
-    else if (strcasecmp(test_name,"DNS_RR") == 0)
-      {
-	scan_dns_args(argc, argv);
-      }
-#endif /* DO_DNS */
-
 }
 
 
